@@ -1,14 +1,14 @@
 """
 Type annotations for dms service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dms/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_dms.literals import AuthMechanismValue
+    from mypy_boto3_dms.literals import AuthMechanismValueType
 
-    data: AuthMechanismValue = "default"
+    data: AuthMechanismValueType = "default"
     ```
 """
 import sys
@@ -20,13 +20,13 @@ else:
 
 
 __all__ = (
-    "AuthMechanismValue",
-    "AuthTypeValue",
-    "CharLengthSemantics",
-    "CompressionTypeValue",
-    "DataFormatValue",
-    "DatePartitionDelimiterValue",
-    "DatePartitionSequenceValue",
+    "AuthMechanismValueType",
+    "AuthTypeValueType",
+    "CharLengthSemanticsType",
+    "CompressionTypeValueType",
+    "DataFormatValueType",
+    "DatePartitionDelimiterValueType",
+    "DatePartitionSequenceValueType",
     "DescribeCertificatesPaginatorName",
     "DescribeConnectionsPaginatorName",
     "DescribeEndpointTypesPaginatorName",
@@ -40,41 +40,41 @@ __all__ = (
     "DescribeReplicationTasksPaginatorName",
     "DescribeSchemasPaginatorName",
     "DescribeTableStatisticsPaginatorName",
-    "DmsSslModeValue",
-    "EncodingTypeValue",
-    "EncryptionModeValue",
+    "DmsSslModeValueType",
+    "EncodingTypeValueType",
+    "EncryptionModeValueType",
     "EndpointDeletedWaiterName",
-    "EndpointSettingTypeValue",
-    "KafkaSecurityProtocol",
-    "MessageFormatValue",
-    "MigrationTypeValue",
-    "NestingLevelValue",
-    "ParquetVersionValue",
-    "RefreshSchemasStatusTypeValue",
-    "ReleaseStatusValues",
-    "ReloadOptionValue",
-    "ReplicationEndpointTypeValue",
+    "EndpointSettingTypeValueType",
+    "KafkaSecurityProtocolType",
+    "MessageFormatValueType",
+    "MigrationTypeValueType",
+    "NestingLevelValueType",
+    "ParquetVersionValueType",
+    "RefreshSchemasStatusTypeValueType",
+    "ReleaseStatusValuesType",
+    "ReloadOptionValueType",
+    "ReplicationEndpointTypeValueType",
     "ReplicationInstanceAvailableWaiterName",
     "ReplicationInstanceDeletedWaiterName",
     "ReplicationTaskDeletedWaiterName",
     "ReplicationTaskReadyWaiterName",
     "ReplicationTaskRunningWaiterName",
     "ReplicationTaskStoppedWaiterName",
-    "SafeguardPolicy",
-    "SourceType",
-    "StartReplicationTaskTypeValue",
-    "TargetDbType",
+    "SafeguardPolicyType",
+    "SourceTypeType",
+    "StartReplicationTaskTypeValueType",
+    "TargetDbTypeType",
     "TestConnectionSucceedsWaiterName",
 )
 
 
-AuthMechanismValue = Literal["default", "mongodb_cr", "scram_sha_1"]
-AuthTypeValue = Literal["no", "password"]
-CharLengthSemantics = Literal["byte", "char", "default"]
-CompressionTypeValue = Literal["gzip", "none"]
-DataFormatValue = Literal["csv", "parquet"]
-DatePartitionDelimiterValue = Literal["DASH", "NONE", "SLASH", "UNDERSCORE"]
-DatePartitionSequenceValue = Literal["DDMMYYYY", "MMYYYYDD", "YYYYMM", "YYYYMMDD", "YYYYMMDDHH"]
+AuthMechanismValueType = Literal["default", "mongodb_cr", "scram_sha_1"]
+AuthTypeValueType = Literal["no", "password"]
+CharLengthSemanticsType = Literal["byte", "char", "default"]
+CompressionTypeValueType = Literal["gzip", "none"]
+DataFormatValueType = Literal["csv", "parquet"]
+DatePartitionDelimiterValueType = Literal["DASH", "NONE", "SLASH", "UNDERSCORE"]
+DatePartitionSequenceValueType = Literal["DDMMYYYY", "MMYYYYDD", "YYYYMM", "YYYYMMDD", "YYYYMMDDHH"]
 DescribeCertificatesPaginatorName = Literal["describe_certificates"]
 DescribeConnectionsPaginatorName = Literal["describe_connections"]
 DescribeEndpointTypesPaginatorName = Literal["describe_endpoint_types"]
@@ -92,32 +92,34 @@ DescribeReplicationTaskAssessmentResultsPaginatorName = Literal[
 DescribeReplicationTasksPaginatorName = Literal["describe_replication_tasks"]
 DescribeSchemasPaginatorName = Literal["describe_schemas"]
 DescribeTableStatisticsPaginatorName = Literal["describe_table_statistics"]
-DmsSslModeValue = Literal["none", "require", "verify-ca", "verify-full"]
-EncodingTypeValue = Literal["plain", "plain-dictionary", "rle-dictionary"]
-EncryptionModeValue = Literal["sse-kms", "sse-s3"]
+DmsSslModeValueType = Literal["none", "require", "verify-ca", "verify-full"]
+EncodingTypeValueType = Literal["plain", "plain-dictionary", "rle-dictionary"]
+EncryptionModeValueType = Literal["sse-kms", "sse-s3"]
 EndpointDeletedWaiterName = Literal["endpoint_deleted"]
-EndpointSettingTypeValue = Literal["boolean", "enum", "integer", "string"]
-KafkaSecurityProtocol = Literal["plaintext", "sasl-ssl", "ssl-authentication", "ssl-encryption"]
-MessageFormatValue = Literal["json", "json-unformatted"]
-MigrationTypeValue = Literal["cdc", "full-load", "full-load-and-cdc"]
-NestingLevelValue = Literal["none", "one"]
-ParquetVersionValue = Literal["parquet-1-0", "parquet-2-0"]
-RefreshSchemasStatusTypeValue = Literal["failed", "refreshing", "successful"]
-ReleaseStatusValues = Literal["beta"]
-ReloadOptionValue = Literal["data-reload", "validate-only"]
-ReplicationEndpointTypeValue = Literal["source", "target"]
+EndpointSettingTypeValueType = Literal["boolean", "enum", "integer", "string"]
+KafkaSecurityProtocolType = Literal["plaintext", "sasl-ssl", "ssl-authentication", "ssl-encryption"]
+MessageFormatValueType = Literal["json", "json-unformatted"]
+MigrationTypeValueType = Literal["cdc", "full-load", "full-load-and-cdc"]
+NestingLevelValueType = Literal["none", "one"]
+ParquetVersionValueType = Literal["parquet-1-0", "parquet-2-0"]
+RefreshSchemasStatusTypeValueType = Literal["failed", "refreshing", "successful"]
+ReleaseStatusValuesType = Literal["beta"]
+ReloadOptionValueType = Literal["data-reload", "validate-only"]
+ReplicationEndpointTypeValueType = Literal["source", "target"]
 ReplicationInstanceAvailableWaiterName = Literal["replication_instance_available"]
 ReplicationInstanceDeletedWaiterName = Literal["replication_instance_deleted"]
 ReplicationTaskDeletedWaiterName = Literal["replication_task_deleted"]
 ReplicationTaskReadyWaiterName = Literal["replication_task_ready"]
 ReplicationTaskRunningWaiterName = Literal["replication_task_running"]
 ReplicationTaskStoppedWaiterName = Literal["replication_task_stopped"]
-SafeguardPolicy = Literal[
+SafeguardPolicyType = Literal[
     "exclusive-automatic-truncation",
     "rely-on-sql-server-replication-agent",
     "shared-automatic-truncation",
 ]
-SourceType = Literal["replication-instance"]
-StartReplicationTaskTypeValue = Literal["reload-target", "resume-processing", "start-replication"]
-TargetDbType = Literal["multiple-databases", "specific-database"]
+SourceTypeType = Literal["replication-instance"]
+StartReplicationTaskTypeValueType = Literal[
+    "reload-target", "resume-processing", "start-replication"
+]
+TargetDbTypeType = Literal["multiple-databases", "specific-database"]
 TestConnectionSucceedsWaiterName = Literal["test_connection_succeeds"]
